==> jc-1.4.0.tar.gz: polyglot/visit/StringPrettyPrinter__24StringCodeWriter.h <==
// public class polyglot.visit.StringPrettyPrinter$StringCodeWriter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bda7215170a25efc polyglot_util_CodeWriter
// @dep_class 9f9fdc9b4ef0b3b7 polyglot_visit_StringPrettyPrinter__24StringCodeWriter

// header file dependencies
// @dep_header polyglot_util_CodeWriter

#include "polyglot/util/CodeWriter.h"

#ifndef _JC_polyglot_visit_StringPrettyPrinter__24StringCodeWriter_H_
#define _JC_polyglot_visit_StringPrettyPrinter__24StringCodeWriter_H_

// Forward structure declarations
struct _jc_java_io_CharArrayWriter$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_visit_StringPrettyPrinter$object;

// Typedefs
typedef struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$sub_refs	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$sub_refs;
typedef struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$sub_nonrefs	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$sub_nonrefs;
typedef struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$refs	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$refs;
typedef struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$nonrefs	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$nonrefs;
typedef struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object;

typedef const struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vmethods	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vmethods;
typedef const struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vtable	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vtable;
typedef const struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vtype	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vtype;

// Constructors
extern void _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method$_init$a36bf5c24fe691a4(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *, struct _jc_polyglot_visit_StringPrettyPrinter$object *, struct _jc_java_io_CharArrayWriter$object *);

// Virtual methods
extern void _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method$allowBreak$2840aaf42817e05c(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *, jint);
extern void _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method$allowBreak$841db7dcd771c63e(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *, jint, struct _jc_java_lang_String$object *);
extern void _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method$begin$a70ea64f2a7c5211(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *, jint);
extern void _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method$newline$87c37c893944ffc4(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *, jint);
extern struct _jc_java_lang_String$object *_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *);
extern void _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method$write$741cedc3a0899944(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method_info$allowBreak$2840aaf42817e05c;
extern _jc_method _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method_info$allowBreak$841db7dcd771c63e;
extern _jc_method _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method_info$begin$a70ea64f2a7c5211;
extern _jc_method _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method_info$newline$87c37c893944ffc4;
extern _jc_method _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method_info$write$741cedc3a0899944;

// Virtual methods structure
struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vmethods {
	void	(*allowBreak$2840aaf42817e05c)(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *, jint);
	void	(*allowBreak$841db7dcd771c63e)(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *, jint, struct _jc_java_lang_String$object *);
	void	(*begin$a70ea64f2a7c5211)(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *, jint);
	void	(*newline$87c37c893944ffc4)(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *, jint);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *);
	void	(*write$741cedc3a0899944)(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_CodeWriter$vmethods	polyglot_util_CodeWriter;
	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vmethods	polyglot_visit_StringPrettyPrinter__24StringCodeWriter;
};

// Vtype
struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vtype {
	_jc_type			type;
	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$sub_refs {
	struct _jc_java_io_CharArrayWriter$object	*w;
	struct _jc_polyglot_visit_StringPrettyPrinter$object	*this__240;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$refs {
    _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$sub_refs	polyglot_visit_StringPrettyPrinter__24StringCodeWriter;
    _jc_polyglot_util_CodeWriter$sub_refs	polyglot_util_CodeWriter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_CodeWriter$sub_nonrefs	polyglot_util_CodeWriter;
    _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$sub_nonrefs	polyglot_visit_StringPrettyPrinter__24StringCodeWriter;
};

// Object instance structure
struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object {
	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vtype	*vtype;
	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vtype _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_StringPrettyPrinter__24StringCodeWriter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$class_object;

#endif	/* _JC_polyglot_visit_StringPrettyPrinter__24StringCodeWriter_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/StringPrettyPrinter__24StringCodeWriter.h <==
// public class polyglot.visit.StringPrettyPrinter$StringCodeWriter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bda7215170a25efc polyglot_util_CodeWriter
// @dep_class 9f9fdc9b4ef0b3b7 polyglot_visit_StringPrettyPrinter__24StringCodeWriter

// header file dependencies
// @dep_header polyglot_util_CodeWriter

#include "polyglot/util/CodeWriter.h"

#ifndef _JC_polyglot_visit_StringPrettyPrinter__24StringCodeWriter_H_
#define _JC_polyglot_visit_StringPrettyPrinter__24StringCodeWriter_H_

// Forward structure declarations
struct _jc_java_io_CharArrayWriter$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_visit_StringPrettyPrinter$object;

// Typedefs
typedef struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$sub_refs	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$sub_refs;
typedef struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$sub_nonrefs	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$sub_nonrefs;
typedef struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$refs	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$refs;
typedef struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$nonrefs	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$nonrefs;
typedef struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object;

typedef const struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vmethods	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vmethods;
typedef const struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vtable	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vtable;
typedef const struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vtype	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vtype;

// Constructors
extern void _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method$_init$a36bf5c24fe691a4(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *, struct _jc_polyglot_visit_StringPrettyPrinter$object *, struct _jc_java_io_CharArrayWriter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method$allowBreak$2840aaf42817e05c(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *, jint) _JC_JCNI_ATTR;
extern void _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method$allowBreak$841db7dcd771c63e(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method$begin$a70ea64f2a7c5211(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *, jint) _JC_JCNI_ATTR;
extern void _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method$newline$87c37c893944ffc4(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method$write$741cedc3a0899944(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method_info$allowBreak$2840aaf42817e05c;
extern _jc_method _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method_info$allowBreak$841db7dcd771c63e;
extern _jc_method _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method_info$begin$a70ea64f2a7c5211;
extern _jc_method _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method_info$newline$87c37c893944ffc4;
extern _jc_method _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$method_info$write$741cedc3a0899944;

// Virtual methods structure
struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vmethods {
	void	(*allowBreak$2840aaf42817e05c)(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *, jint) _JC_JCNI_ATTR;
	void	(*allowBreak$841db7dcd771c63e)(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*begin$a70ea64f2a7c5211)(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *, jint) _JC_JCNI_ATTR;
	void	(*newline$87c37c893944ffc4)(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *) _JC_JCNI_ATTR;
	void	(*write$741cedc3a0899944)(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_CodeWriter$vmethods	polyglot_util_CodeWriter;
	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vmethods	polyglot_visit_StringPrettyPrinter__24StringCodeWriter;
};

// Vtype
struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vtype {
	_jc_type			type;
	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$sub_refs {
	struct _jc_java_io_CharArrayWriter$object	*w;
	struct _jc_polyglot_visit_StringPrettyPrinter$object	*this__240;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$refs {
    _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$sub_refs	polyglot_visit_StringPrettyPrinter__24StringCodeWriter;
    _jc_polyglot_util_CodeWriter$sub_refs	polyglot_util_CodeWriter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_CodeWriter$sub_nonrefs	polyglot_util_CodeWriter;
    _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$sub_nonrefs	polyglot_visit_StringPrettyPrinter__24StringCodeWriter;
};

// Object instance structure
struct _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$object {
	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vtype	*vtype;
	_jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$vtype _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_StringPrettyPrinter__24StringCodeWriter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_StringPrettyPrinter__24StringCodeWriter$class_object;

#endif	/* _JC_polyglot_visit_StringPrettyPrinter__24StringCodeWriter_H_ */
